@@ -1,27 +1,28 @@
-from cdh_dav_python.cdc_admin_service.environment_logging import LoggerSingleton
-
-from cdh_dav_python.cdc_tech_environment_service import environment_http as cdc_env_http
-
-
-import requests
-import json
-from .db_column import Column
-
-
+# Standard core library imports
 import os
 import sys
+
+# Standard library imports
+import json
 import re
 import math
+
+# Third-party imports
+import requests
 import pandas as pd
 
-# Default request time out
-REQUEST_TIMEOUT = 180
+# Local application/library specific imports
+from cdh_dav_python.cdc_admin_service.environment_logging import LoggerSingleton
+from cdh_dav_python.cdc_tech_environment_service import environment_http as cdc_env_http
+
+# Constants
 # Get the currently running file name
 NAMESPACE_NAME = os.path.basename(os.path.dirname(__file__))
 # Get the parent folder name of the running file
 SERVICE_NAME = os.path.basename(__file__)
 # Default limit item number of items to retrieve
 LIMIT = 500
+REQUEST_TIMEOUT = 60
 
 
 class EdcAlationError(Exception):
@@ -66,17 +67,7 @@ class CustomFields:
 
     def __init__(self):
         """
-        Create an endpoint object.
-
-        Parameters
-        ----------
-        token: string
-            The Alation API Access token to interact with the API. See
-            https://developer.alation.com/dev/docs/authentication-into-alation-apis#create-api-access-token
-            for details.
-        base_url: string
-            The root URL for the Alation server to use. It should not have a slash "/" at the end of the URL.
-            Example: https://edc.cdc.gov
+        Initializes an instance of the CustomFields class.
         """
         self.updates = []
 
@@ -152,7 +143,9 @@ class CustomFields:
             If 'title' or 'description' is None, it is not included in the dictionary.
             If both are None, an empty dictionary is returned.
         """
+
         from .db_table import Table
+        from .db_column import Column
 
         if isinstance(fields, (Column, Table)):
             return {
@@ -428,6 +421,15 @@ class CustomFields:
         return f'"{key}"'  # Wrap the key with double quotes
 
     def encode_key_with_special_characters(self, key):
+        """
+        Encodes a key by replacing special characters with their corresponding escape sequences.
+
+        Args:
+            key (str): The key to be encoded.
+
+        Returns:
+            str: The encoded key.
+        """
         special_characters = {
             "!": "%21",
             '"': "%22",
@@ -468,10 +470,29 @@ class CustomFields:
         return key
 
     def handle_null(self, value):
+        """
+        Handles null values by returning the original value if it is not None,
+        otherwise returns "N/A".
+
+        Args:
+            value: The value to be handled.
+
+        Returns:
+            The original value if it is not None, otherwise "N/A".
+        """
         return value if value is not None else "N/A"
 
     # Recursive function to replace null with empty string
     def replace_null_with_empty(self, obj):
+        """
+        Recursively replaces null values in a dictionary or list with "N/A".
+
+        Args:
+            obj (dict or list): The object to process.
+
+        Returns:
+            dict or list: The processed object with null values replaced by "N/A".
+        """
         if isinstance(obj, dict):
             return {
                 k: self.replace_null_with_empty(v) if v is not None else "N/A"
@@ -559,6 +580,8 @@ class CustomFields:
         ).initialize_logging_and_tracing()
 
         with tracer.start_as_current_span("update"):
+            logger.info(f"date_fields: {date_fields} not yet supported")
+
             array_of_json = None
             try:
                 batch_size = 50
@@ -567,8 +590,10 @@ class CustomFields:
 
                 # Check if the fields_dict is a Table object
                 # If it is a Table object, then extract the properties (attributes) to a dictionary with key-value pairs
-                from .db_table import Table
 
+                from .db_table import Table
+                from .db_column import Column
+                
                 if isinstance(fields_dict, Table):
                     # Extract properties (attributes) to a dictionary with key-value pairs
                     fields_dict = vars(fields_dict)
@@ -773,9 +798,18 @@ class EnhancedJSONEncoder(json.JSONEncoder):
 
     """
 
-    def default(self, obj):
-        if isinstance(obj, pd.Timestamp):
-            return obj.strftime("%Y-%m-%d %H:%M:%S")
-        elif pd.isna(obj):  # This checks for both NaT and NaN
+    def default(self, o):
+        """
+        Convert the given object to a JSON serializable format.
+
+        Args:
+            o: The object to be converted.
+
+        Returns:
+            The JSON serializable representation of the object.
+        """
+        if isinstance(o, pd.Timestamp):
+            return o.strftime("%Y-%m-%d %H:%M:%S")
+        elif pd.isna(o):  # This checks for both NaT and NaN
             return None  # or use a string like "null" or "missing"
-        return super().default(obj)
+        return super().default(o)
