@@ -5,10 +5,9 @@ import sys
 from opentelemetry import trace
 from dotenv import load_dotenv, set_key, dotenv_values
 
-from cdh_dav_python.cdc_admin_service import (
-    environment_tracing as cdh_env_tracing,
-    environment_logging as cdh_env_logging,
-)
+from cdh_dav_python.cdc_admin_service.environment_logging import LoggerSingleton
+
+ 
 
 
 from cdh_dav_python.az_key_vault_service import (
@@ -29,13 +28,6 @@ class EdcAlationTokenError(Exception):
 
 
 class TokenEndpoint:
-    """
-    This is a class for managing tokens for use with the Alation API.
-
-    For details of the API tokens, see:
-    https://developer.alation.com/dev/docs/authentication-into-alation-apis
-    """
-
     def __init__(self, base_url):
         """
         Creates a TokenEndpoint object
@@ -68,27 +60,15 @@ class TokenEndpoint:
             tuple: A tuple containing the status code and either the API access token or an error message.
         """
 
-        logger_singleton = cdh_env_logging.LoggerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        logger = logger_singleton.get_logger()
-        tracer_singleton = cdh_env_tracing.TracerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        tracer = tracer_singleton.get_tracer()
+        data_product_id = config.get("data_product_id")
+        environment = config.get("environment")
+        
+        tracer, logger = LoggerSingleton.instance(
+            NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+        ).initialize_logging_and_tracing()
 
         with tracer.start_as_current_span("get_api_token_from_config"):
             try:
-                logger_singleton = cdh_env_logging.LoggerSingleton.instance(
-                    NAMESPACE_NAME, SERVICE_NAME
-                )
-                logger = logger_singleton.get_logger()
-                cdh_env_tracing.TracerSingleton.log_to_console = False
-                tracer_singleton = cdh_env_tracing.TracerSingleton.instance(
-                    NAMESPACE_NAME, SERVICE_NAME
-                )
-                tracer = tracer_singleton.get_tracer()
-
                 edc_alation_base_url = config.get("edc_alation_base_url")
                 edc_alation_user_id = config.get("edc_alation_user_id")
                 az_sub_tenant_id = config.get("az_sub_tenant_id")
@@ -116,18 +96,21 @@ class TokenEndpoint:
                     client_secret,
                     az_kv_key_vault_name,
                     running_interactive,
+                    data_product_id,
+                    environment,
                 )
-                az_kv_edc_refresh_secret_key = config.get(
-                    "az_kv_edc_refresh_secret_key"
+                cdh_alation_refresh_secret_key = config.get(
+                    "cdh_alation_refresh_secret_key"
                 )
                 logger.info(
-                    f"az_kv_edc_refresh_secret_key: {az_kv_edc_refresh_secret_key}"
+                    f"cdh_alation_refresh_secret_key: {cdh_alation_refresh_secret_key}"
                 )
                 logger.info(
-                    f"az_kv_edc_refresh_secret_key_length:{str(len(az_kv_edc_refresh_secret_key))}"
+                    f"cdh_alation_refresh_secret_key_length:{str(len(cdh_alation_refresh_secret_key))}"
                 )
+                cdh_databricks_kv_scope = config.get("cdh_databricks_kv_scope")
                 alation_refresh_token = az_key_vault.get_secret(
-                    az_kv_edc_refresh_secret_key
+                    cdh_alation_refresh_secret_key, cdh_databricks_kv_scope
                 )
                 edc_alation_api_token = self.get_api_token(
                     edc_alation_base_url,
@@ -147,7 +130,9 @@ class TokenEndpoint:
             except Exception as ex:
                 error_msg = (f"Error: {str(ex)}",)
                 exc_info = sys.exc_info()
-                logger_singleton.error_with_exception(error_msg, exc_info)
+                LoggerSingleton.instance(
+                    NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+                ).error_with_exception(error_msg, exc_info)
                 raise
 
     def validate_api_token(self, edc_alation_base_url, edc_alation_api_token, user_id):
@@ -162,14 +147,9 @@ class TokenEndpoint:
             True if the token is valid, False otherwise.
         """
 
-        logger_singleton = cdh_env_logging.LoggerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        logger = logger_singleton.get_logger()
-        tracer_singleton = cdh_env_tracing.TracerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        tracer = tracer_singleton.get_tracer()
+        tracer, logger = LoggerSingleton.instance(
+            NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+        ).initialize_logging_and_tracing()
 
         with tracer.start_as_current_span("validate_api_token"):
             api_url = f"{edc_alation_base_url}/integration/v1/validateAPIAccessToken/"
@@ -238,17 +218,13 @@ class TokenEndpoint:
         logger_singleton = cdh_env_logging.LoggerSingleton.instance(
             NAMESPACE_NAME, SERVICE_NAME
         )
-        logger = logger_singleton.get_logger()
-        tracer_singleton = cdh_env_tracing.TracerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        tracer = tracer_singleton.get_tracer()
+
 
         with tracer.start_as_current_span("get_api_token"):
             try:
                 dotenv_path = os.path.join(os.path.dirname(__file__), ".env")
                 load_dotenv(dotenv_path)
-                # Load environment variables from .env file
+                # Load environment variables from env file
                 env_variables = dotenv_values(dotenv_path)
                 # Check if the API access token is already stored in an environment variable
                 edc_alation_api_token = env_variables.get("API_ACCESS_TOKEN")
@@ -276,7 +252,9 @@ class TokenEndpoint:
             except Exception as ex:
                 error_msg = "Error: %s", ex
                 exc_info = sys.exc_info()
-                logger_singleton.error_with_exception(error_msg, exc_info)
+                LoggerSingleton.instance(
+                    NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+                ).error_with_exception(error_msg, exc_info)
                 raise
 
     def validate_refresh_token(self, user_id, refresh_token):
@@ -361,15 +339,9 @@ class TokenEndpoint:
             str: The API token.
         """
 
-        logger_singleton = cdh_env_logging.LoggerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        logger = logger_singleton.get_logger()
-        cdh_env_tracing.TracerSingleton.log_to_console = False
-        tracer_singleton = cdh_env_tracing.TracerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        tracer = tracer_singleton.get_tracer()
+        tracer, logger = LoggerSingleton.instance(
+            NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+        ).initialize_logging_and_tracing()
 
         with tracer.start_as_current_span(f"getAPIToken"):
             logger.info(
@@ -462,15 +434,13 @@ class TokenEndpoint:
     # Won't work for CDC because we use SSO
     @staticmethod
     def create_alation_refresh_token(config):
-        logger_singleton = cdh_env_logging.LoggerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        logger = logger_singleton.get_logger()
-        cdh_env_tracing.TracerSingleton.log_to_console = False
-        tracer_singleton = cdh_env_tracing.TracerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        tracer = tracer_singleton.get_tracer()
+        
+        data_product_id = config.get("data_product_id")
+        environment = config.get("environment")
+        
+        tracer, logger = LoggerSingleton.instance(
+            NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+        ).initialize_logging_and_tracing()
 
         with tracer.start_as_current_span(f"create_alation_refresh_token"):
             edc_alation_base_url = config.get("edc_alation_base_url")
@@ -500,7 +470,7 @@ class TokenEndpoint:
 
     @staticmethod
     def create_api_access_token_via_refresh(
-        edc_alation_base_url, edc_alation_user_id, edc_alation_refresh_token
+        edc_alation_base_url, edc_alation_user_id, edc_alation_refresh_token, data_product_id, environment
     ):
         """
         This function creates a new API access token using a refresh token.
@@ -514,13 +484,9 @@ class TokenEndpoint:
         dict: The new API access token.
         """
 
-        logger_singleton = cdh_env_logging.LoggerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        logger = logger_singleton.get_logger()
-        cdh_env_tracing.TracerSingleton.log_to_console = False
-        tracer_singleton = cdh_env_tracing.TracerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
+        tracer, logger = LoggerSingleton.instance(
+            NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+        ).initialize_logging_and_tracing()
         )
         tracer = tracer_singleton.get_tracer()
 
@@ -577,15 +543,9 @@ class TokenEndpoint:
             str: The API token if the request is successful, "not_set" otherwise.
         """
 
-        logger_singleton = cdh_env_logging.LoggerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        logger = logger_singleton.get_logger()
-        cdh_env_tracing.TracerSingleton.log_to_console = False
-        tracer_singleton = cdh_env_tracing.TracerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        tracer = tracer_singleton.get_tracer()
+        tracer, logger = LoggerSingleton.instance(
+            NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+        ).initialize_logging_and_tracing()
 
         with tracer.start_as_current_span(f"create_api_access_token_via_login"):
             edc_alation_base_url = config.get("edc_alation_base_url")
@@ -637,15 +597,9 @@ class TokenEndpoint:
             str: The API access token.
         """
 
-        logger_singleton = cdh_env_logging.LoggerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        logger = logger_singleton.get_logger()
-        cdh_env_tracing.TracerSingleton.log_to_console = False
-        tracer_singleton = cdh_env_tracing.TracerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        tracer = tracer_singleton.get_tracer()
+        tracer, logger = LoggerSingleton.instance(
+            NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+        ).initialize_logging_and_tracing()
 
         with tracer.start_as_current_span(f"get_edc_alation_api_access_token"):
             api_token = cls.create_api_access_token_via_refresh(
