@@ -1,5 +1,5 @@
 """
-This module, app.py, serves as the primary entry point to the Program Agnostic Data Ecosystem (CDH) application. It initializes the application and sets up the endpoints for various services, including Alation.
+This module, app.py, serves as the primary entry point to the CDC Data Hub LAVA (CDH-LAVA) application. It initializes the application and sets up the endpoints for various services, including Alation.
 
 The Alation service is specifically designed to manage and monitor Alation. It provides the following API endpoints:
 
@@ -63,7 +63,7 @@ except ModuleNotFoundError as ex:
     # logger_singleton.error_with_exception(error_message, exc_info)
     raise ex
 
-from cdh_dav_python.alation_service import db_schema as alation_schema
+import cdh_dav_python.alation_service.db_schema as alation_schema
 from cdh_dav_python.cdc_tech_environment_service import (
     environment_file as cdc_env_file,
 )
@@ -480,13 +480,25 @@ def error():
 
 @cdc_admin_bp.route("/get_log_file_tail/<int:number_of_lines>")
 def get_log_file_tail(number_of_lines):
-    """Get the last n lines of the log file"""
+    """
+    Retrieves the tail of a log file and renders it in an HTML template.
+
+    Args:
+        number_of_lines (int): The number of lines to retrieve from the log file.
+
+    Returns:
+        str: The rendered HTML template containing the log file entries.
+
+    Raises:
+        Exception: If an internal server error occurs while fetching the log file.
+        ValueError: If the log data is None, or if the number_of_lines is missing or blank.
+    """
 
     tracer, logger = LoggerSingleton.instance(
         NAMESPACE_NAME, SERVICE_NAME, DATA_PRODUCT_ID, ENVIRONMENT
     ).initialize_logging_and_tracing()
 
-    with tracer.start_as_current_span(f"get_log_file_tail"):
+    with tracer.start_as_current_span("get_log_file_tail"):
         try:
             log_data = None
 
@@ -494,7 +506,9 @@ def get_log_file_tail(number_of_lines):
                 status_code,
                 number_of_lines,
                 log_data,
-            ) = logger.get_log_file_tail(number_of_lines)
+            ) = LoggerSingleton.instance(
+                NAMESPACE_NAME, SERVICE_NAME, DATA_PRODUCT_ID, ENVIRONMENT
+            ).get_log_file_tail(number_of_lines)
             if status_code == 500:
                 error_msg = f"Internal Server Error fetching log file: The server encountered an error. {log_data}"
                 raise Exception(error_msg)
@@ -506,7 +520,7 @@ def get_log_file_tail(number_of_lines):
 
             if number_of_lines is None or number_of_lines == 0:
                 raise ValueError(
-                    f"Internal Server Error fetching log file: number_of_lines is missing or blank"
+                    "Internal Server Error fetching log file: number_of_lines is missing or blank"
                 )
 
             log_entries = []
@@ -552,7 +566,7 @@ FlaskInstrumentor().instrument_app(app)
 
 API_DESCRIPTION = """
 <h2>API Documentation</h2>
-<p>The Program Agnostic Data Ecosystem (CDH) provides shared resources,
+<p>The Program Agnostic CDC Data Hub LAVA (CDH) provides shared resources,
 practices and guardrails for analysts to discover, access, link, and use
 agency data in a consistent way. CDH improvements in standardized and 
 streamlined workflows reduce the effort required to find, access, and
