@@ -1,8 +1,6 @@
 """Initialize the az_key_vault_service subpackage of cdh_dav_python package"""
 # allow absolute import from the root folder
 # whatever its name is.
-from ..cdc_admin_service import environment_tracing
-from ..cdc_admin_service import environment_logging
 import sys  # don't remove required for error handling
 import os
 
@@ -21,5 +19,6 @@ else:
     sys.path.append(os.path.dirname(os.path.abspath(__file__ + "/../..")))
     sys.path.append(os.path.dirname(os.path.abspath(__file__ + "/../../..")))
 
+import cdh_dav_python.az_key_vault_service.az_key_vault
 
-__all__ = ["az_client", "azd_client"]
+__all__ = ["az_key_vault"]
