@@ -23,16 +23,6 @@ else:
     sys.path.append(os.path.dirname(os.path.abspath(__file__ + "/../..")))
     sys.path.append(os.path.dirname(os.path.abspath(__file__ + "/../../..")))
 
-import cdh_dav_python.databricks_service.notebook
-import cdh_dav_python.databricks_service.secret_scope
-import cdh_dav_python.databricks_service.workspace
-import cdh_dav_python.databricks_service.dataset_crud
-import cdh_dav_python.databricks_service.dataset_core
-import cdh_dav_python.databricks_service.dataset_convert
-import cdh_dav_python.databricks_service.dataset_extract
-import cdh_dav_python.databricks_service.database
-import cdh_dav_python.databricks_service.cluster
-
 __all__ = [
     "database",
     "dataset_convert",
