@@ -1,6 +1,5 @@
 # Import from sibling directory ..\databricks_service
-from ..cdc_admin_service import environment_tracing
-from ..cdc_admin_service import environment_logging
+
 import sys
 import os
 
@@ -18,5 +17,9 @@ else:
     sys.path.append(os.path.dirname(os.path.abspath(__file__ + "/../..")))
     sys.path.append(os.path.dirname(os.path.abspath(__file__ + "/../../..")))
 
+import cdh_dav_python.github_service.github_secret
+import cdh_dav_python.github_service.github_release
+import cdh_dav_python.github_service.github_issue
 
-__all__ = ["github_secret"]
+
+__all__ = ["github_secret", "github_release", "github_issue"]
