@@ -7,6 +7,7 @@ from html.parser import HTMLParser  # web scraping html
 import subprocess
 import os
 
+from cdh_dav_python.cdc_admin_service.environment_logging import LoggerSingleton
 
 # Get the currently running file name
 NAMESPACE_NAME = os.path.basename(os.path.dirname(__file__))
@@ -113,15 +114,7 @@ class GitHubSecret:
         Raises:
             subprocess.CalledProcessError: If an error occurs while making the API request.
         """
-        logger_singleton = cdc_env_logging.LoggerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        logger = logger_singleton.get_logger()
-        cdc_env_tracing.TracerSingleton.log_to_console = False
-        tracer_singleton = cdc_env_tracing.TracerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        tracer = tracer_singleton.get_tracer()
+        logger_singleton = LoggerSingleton.instance(NAMESPACE_NAME, SERVICE_NAME)
 
         # Check if user is logged in
         try:
