@@ -3,9 +3,11 @@ import requests
 from typing import List
 import json
 
+REQUEST_TIMEOUT = 180
+
 from cdh_dav_python.cdc_admin_service.environment_logging import LoggerSingleton
+from cdh_dav_python.cdc_tech_environment_service.environment_http import EnvironmentHttp
 
-from cdh_dav_python.cdc_tech_environment_service import environment_file as cdc_env_file
 
 # Get the currently running file name
 NAMESPACE_NAME = os.path.basename(os.path.dirname(__file__))
@@ -38,11 +40,21 @@ class PositConnect:
             headers = {"Authorization": f"Key {api_key}"}
 
             api_url = f"{posit_connect_base_url}/__api__/v1/server_settings/r"
-            response = requests.get(api_url, headers=headers)
+
+            obj_http = EnvironmentHttp()
+            params = {}
+            response = obj_http.get(
+                api_url, headers, REQUEST_TIMEOUT, params, data_product_id, environment
+            )
 
             # If the request was successful, status_code will be 200
             status_code = response.status_code
 
+            # Check the status code
+            if status_code != 200:
+                # Raise an exception if the status code is not 200 (OK)
+                response.raise_for_status()
+
             # If the request was successful, status_code will be 200
             logger.info(f"response.status_code: {response.status_code}")
 
@@ -58,7 +70,9 @@ class PositConnect:
             return status_code, response_content, api_url
 
     @staticmethod
-    def get_python_information(api_key, posit_connect_base_url):
+    def get_python_information(
+        api_key, posit_connect_base_url, data_product_id, environment
+    ):
         """
         Gets POSIT Python configuration information by making a request to a specified URL.
 
@@ -149,7 +163,9 @@ class PositConnect:
             return status_code, response_content, api_url
 
     @staticmethod
-    def generate_manifest(swagger_file, requirements_file):
+    def generate_manifest(
+        swagger_file, requirements_file, data_product_id, environment
+    ):
         """
         Generate the manifest.json file based on the current swagger and requirements.txt.
 
@@ -161,7 +177,6 @@ class PositConnect:
             str: The path to the generated manifest.json file. This file includes a summary of the application's structure and dependencies.
         """
 
-        cdc_env_tracing.TracerSingleton.log_to_console = False
         tracer, logger = LoggerSingleton.instance(
             NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
         ).initialize_logging_and_tracing()
